==> identity_firebase-0.1.0.tar.gz: lib/src/firebase_email_authenticator.dart <==
import 'package:firebase_auth/firebase_auth.dart';
import 'package:flutter/material.dart';
import 'package:identity/identity.dart';
import 'package:sso/sso.dart';

import 'email_signin_page.dart';
import 'firebase_provider.dart';

class FirebaseEmailAuthenticator implements Authenticator {
  const FirebaseEmailAuthenticator();

  @override
  WidgetBuilder get action => (context) => ActionButton(
      onPressed: () => Navigator.push(context,
          MaterialPageRoute(builder: (context) => EmailSignInPage(this))),
      color: Color.fromRGBO(75, 78, 95, 1),
      textColor: Colors.white,
      icon: Icon(
        Icons.email,
        color: Color.fromRGBO(75, 78, 95, 1),
      ),
      text: "Sign In With Email");

  @override
  Future<void> authenticate(BuildContext context, [Map parameters]) async {
    _validate(parameters);
    return FirebaseAuth.instance
        .signInWithEmailAndPassword(
            email: parameters["email"], password: parameters["password"])
        .then((result) => FirebaseProvider.convert(result.user))
        .then((user) => Identity.of(context).user = user)
        .catchError(Identity.of(context).error);
  }

  Future<void> register(BuildContext context, [Map parameters]) async {
    _validate(parameters);
    return FirebaseAuth.instance
        .createUserWithEmailAndPassword(
            email: parameters["email"], password: parameters["password"])
        .then((result) async {
          if (result.user.isEmailVerified == false) {
            await result.user.sendEmailVerification();
          }

          return FirebaseProvider.convert(result.user);
        })
        .then((user) => Identity.of(context).user = user)
        .catchError(Identity.of(context).error);
  }

  void _validate(Map parameters) {
    assert(parameters != null);
    assert(parameters["email"] != null);
    assert(parameters["password"] != null);
  }
}

==> identity_firebase-0.2.0.tar.gz: lib/src/firebase_email_authenticator.dart <==
import 'package:firebase_auth/firebase_auth.dart';
import 'package:flutter/material.dart';
import 'package:identity/identity.dart';
import 'package:sso/sso.dart';

import 'email_signin_page.dart';

class FirebaseEmailAuthenticator with WillConvertUser implements Authenticator {
  FirebaseEmailAuthenticator();

  @override
  WidgetBuilder get action => (context) => ActionButton(
      onPressed: () => Navigator.push(context,
          MaterialPageRoute(builder: (context) => EmailSignInPage(this))),
      color: Color.fromRGBO(75, 78, 95, 1),
      textColor: Colors.white,
      icon: Icon(
        Icons.email,
        color: Color.fromRGBO(75, 78, 95, 1),
      ),
      text: "Sign In With Email");

  @override
  Future<void> authenticate(BuildContext context, [Map parameters]) async {
    _validate(parameters);
    return FirebaseAuth.instance
        .signInWithEmailAndPassword(
            email: parameters["email"], password: parameters["password"])
        .then((result) => convert(result.user))
        .then((user) => Identity.of(context).user = user)
        .catchError(Identity.of(context).error);
  }

  Future<void> register(BuildContext context, [Map parameters]) async {
    _validate(parameters);
    return FirebaseAuth.instance
        .createUserWithEmailAndPassword(
            email: parameters["email"], password: parameters["password"])
        .then((result) async {
          if (result.user.isEmailVerified == false) {
            await result.user.sendEmailVerification();
          }

          return convert(result.user);
        })
        .then((user) => Identity.of(context).user = user)
        .catchError(Identity.of(context).error);
  }

  void _validate(Map parameters) {
    assert(parameters != null);
    assert(parameters["email"] != null);
    assert(parameters["password"] != null);
  }
}
